calculate_bathymetry: Calculate bathymetric-related metrics

Description Usage Arguments Value

View source: R/calculate_bathymetry.R

Description

Given a data frame with the metrics for a single set of simulations, calculate the associated volume (m3), area (m2), maximum depth (m), and mean depth (m) for each exceedance_level (m). Uses CSLSdata::bathymetry and CSLSdata::lake_raster, only performs calculations on lakes which have information in all three data sources.

Usage

1

Arguments

df

a data frame with a "lake", "metric", "variable", and "value" columns where one of the metrics is "exceedance_level".

Value

bathymetry, a data frame with "lake", "metric", "variable", and "value" where the metrics are "volume", "area", "max_depth", and "mean_depth" and the variables are all the exceedance level probabilities inputted in df.


WDNR-Water-Use/CSLSscenarios documentation built on Nov. 10, 2021, 4:14 p.m.