extrapolate_bathymetry: Extrapolate relationship between elevation and bathymetric...

Description Usage Arguments Details Value

View source: R/extrapolate_bathymetry.R

Description

Assumes ecological rule is a percent change (increase or decrease) from baseline value (e.g., 10% decrease), not a numerical difference (e.g., 2 fewer times).

Usage

1
2
3
4
5
6
7
extrapolate_bathymetry(
  this_hydro,
  this_rule,
  bathymetry,
  bathy_metric,
  metric_uncertainty
)

Arguments

this_hydro

data frame with the hydrologic metrics (exceedance levels) to evaluate.

this_rule

data frame with the ecological rules for given parameter to evaluate.

bathymetry

data frame with relationships between lake elevation and other parameters (e.g., lake area, lake volume, plant area, substrate area)

bathy_metric

name of column in bathymetry to evaluate

metric_uncertainty

data frame with lake, metric, variable, and allowable "difference" due to uncertainty in the metric. Currently evaluated as the standard deviation in the "no irrigation" scenarios of the metric.

Details

Because so many bathymetric relationships are non-monotonic, had to come up with a hacky way of finding correct elevation match for given threshold child bathy parameter. From check on monotonic child parameters, should yield accurate threshold elevations to within 1 cm.

Value

impact_evaluation, a data frame with the following columns:

lake

name of lake, character

metric

hydrologic metric, i.e. "exceedance_level"

variable

hydrologic metric variable, i.e. 10, 25, 50, 75, or 90

value1

baseline value for hydrologic metric

threshold

threshold value for hydrologic metric for impact

value2

scenario value for hydrologic metric

impacted

logical, indicates whether lake is impacted relative to this ecological indicator under this scenario (TRUE) or not (FALSE)


WDNR-Water-Use/CSLSscenarios documentation built on Nov. 10, 2021, 4:14 p.m.