Description Usage Arguments Value
View source: R/calculate_bathymetry.R
Given a data frame with the metrics for a single set of simulations, calculate the associated volume (m3), area (m2), maximum depth (m), and mean depth (m) for each exceedance_level (m). Uses CSLSdata::bathymetry and CSLSdata::lake_raster, only performs calculations on lakes which have information in all three data sources.
1 |
df |
a data frame with a "lake", "metric", "variable", and "value" columns where one of the metrics is "exceedance_level". |
bathymetry, a data frame with "lake", "metric", "variable", and "value" where the metrics are "volume", "area", "max_depth", and "mean_depth" and the variables are all the exceedance level probabilities inputted in df.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.